bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 27. Aventiure
___________________________________________________
| ### Do gie der margrave da er di vrovn vant ### sin wip mit siner tohter vnt sagete in zehant ### div vil lieben mære div er het vernomen ### daz in ir frovn brvder dar ce hvse solden chomen
###### 1648 | ### Vil liebiv trvetinne sprach do Rvedger ### ir svlt vil wol enpfahen di edelen chvenige her ### so si mit ir gesinde her ce hove gan ### ir svlt ovch schone grvezen Hagen Gventheres man
###### 1649 | ### Mit in chvmt ovch einer der heizet Danchwart ### der ander heizet Volker an zvehten wol bewart ### di sehse svlt ir chvessen vnt div tohter min ### vnde svlt ovch bi den recken in zvehten gvetliche sin
| ### Daz lobten do di vrowen vnd warn sin bereit ### si svchten vz den chisten div herlichen chleit ### dar inne si engegene den recken wolden gan ### da wart vil michel vlizen von schoenen wiben getan
###### 1651 | ### Gevelshet frovn varwe vil lvecel man da vant ### si trvgen vf ir hovbete von golde liehtiv bant ### daz waren shapel riche daz in ir schoene har ### cefvrten niht di winde daz ist an den triwen war
###### 1652 | ### In solhen vnmvzen svl wir di vrowen lan ### hi wart vil michel gahen veber velt getan ### von Rvedgeres vrivnden da man di fversten vant ### si wrden wol enpfangen in des margraven lant
| ### Do si der margrave zv zim chomen sach ### Rvedger der snelle vil vroeliche sprach ### sit willechomen ir herren vnd ovch iwer man ### hie in minem lande vil gern ich ivh gesehen han
###### 1654 | ### Do nigen im di recken mit triwen ane haz ### daz er in willech wære vil wol erzeigete er daz ### besvnder grvzte er Hagenen den het er ê bechant ### alsam tet er Volkern vzer Bvrgonden lant
###### 1655 | ### Er enpfie ovch Danchwarten do sprach der [373a] chvene degen ### sit ir vns welt bervchen nv wer <sol> danne pflegen ### des vnsern ingesindes daz wir haben braht ### do sprach der margrave ir svlt haben gvte naht
| ### Vnd allez iwer gesinde swaz ir in daz lant ### habt mit iv gefveret ross vnd ovch gewant ### dem shaffe ich soelhe hvte daz sin niht verlorn ### daz iv ce shaden bringe gegen enigem sporn
###### 1657 | ### Spannet vf ir knehte di hvetten an daz velt ### swaz ir hie verlieset des wil ich wesen gelt ### ziehet ab di zovme div ross lazet gan ### daz het in wirt deheiner da vor vil selten getan
###### 1658 | ### Des <vrevten> sich di geste do daz geshaffen was ### di herren riten dannen sich leiten an daz gras ### vber al di knehte si heten gvt gemach ### ich wæne in an dirre verte ni so sanfte geshach
| ### Div edele margravinne was di fver di bvrch gegan ### mit ir vil schoenen tohter do sah man bi ir stan ### di minnechlichen vrowen vnd manige <shoen> meit ### di trvgen vil der bovge vnd ovch herlichiv chleit
###### 1660 | ### Daz edel gesteine lvhte verre dan ### vz ir vil richen wæte si waren wolgetan ### do chomen ovch di geste vnd erbeizten sa cehant ### hey waz man grozer zvehte an den Bvrgonden vant
###### 1661 | ### Sehs vnt drizech mægde vnt manich ander wip ### den was wol ce wnshe geshaffen gar der lip ### di giengen in engegene mit manigem chvenem man ### da wart ein shoene grvezen von edeln vrowen getan
| ### Div edele margravinne chvste di kvenige alle dri ### alsam tet ir mvter da stvnt ovch Hagen bi ### ir vater hiez in chvessen do blichte si in an ### er dvhte si so vorhtlich daz siz vil gerne hete lan
###### 1663 | ### Do mv^ste si daz leisten daz ir der wirt gebot ### gemisschet wart ir varwe bleich vnde rot ### si chvste ovch Danchwarten dar nach den spileman ### dvrch sines libes ellen wart im daz grvzen getan
###### 1664 | ### Div ivnge margravinne div nam bi der hant ### Giselher den recken von Bvrgonden lant ### alsam tet ovch ir mvter [373b] Gventher der chvenen man ### si giengen mit den helden vil harte vroliche dan
###### 1665 | ### <der> wirt gi bi Gernote in einen witen sal ### ritter vnd vrowen gesazen da ce tal ### do hiez man balde shenchen den gesten gvten win ### iane dorften nimmer helde baz gehandelet sin
###### 1666 | ### Mit lieben ovgen blicken wart gesehen an ### div Rvedgeres tohter div was so wol getan ### ia trvtes in den sinnen vil manich ritter gvt ### daz chonde ovch si verdienen si was hohe gemvt
###### 1667 | ### Si dahten swes si wolden des enmohte aver niht geshehen ### hin vnd her wider wart da vil gesehen ### an mageden vnd an vrowen der saz da genvch ### der edel videlære dem wirte holden willen trvch
| ### Nach gewonheite so schieden si sich da ### ritter vnd vrowen di giengen anderswa ### do rihte man di tisshe in dem sale wit ### den vnchvnden gesten diente man herliche sit
###### 1669 | ### Dvrch der geste liebe hin ce tisshe gie ### div edele margravinne ir tohter si do lie ### beliben bi den chinden da si von rehte saz ### di geste ir niht ensahen si mvte wærliche daz
###### 1670 | ### Do si getrvnchen heten vnd gezen veber al ### do wiste man di schoenen wider in den sal ### gæmlicher sprveche wart da niht verdeit ### der redete vil do Volker ein degen chven vnt gemeit
| ### Do sprach offenlichen der edel spilman ### richer margrave got hat an iv getan ### vil genædechlichen wand er iv hat gegeben ### ein wip so rehte schoene dar zv ein wnnechlichez leben
###### 1672 | ### Ob ich ein fverste wære sprach der spilman ### vnd <solde> ich tragen chrone ce wibe wold ich han ### di iwern schoenen tohter des wensshet mir der mvt ### div ist minnechlich ce sehen dar zv edel vnd gvt
###### 1673 | ### Do sprach der margrave wi moehte daz gesin ### daz immer kvenech gerte der lieben tohter min ### wir sin hi ellende beide ich vnd min wip ### waz hilfet groziv schoene an der ivnchvrowen lip
| ### Des antwrte Gernot der wolgezogen man ### vnd sold ich trivttinne nach minem willen han ### so wold ich [374a] solhes wibes immer wesen vro ### <des> antwrte Hagene vil harte gvetlichen do
###### 1675 | ### Nv sol min herre Giselher doch nemen ein wip ### ez ist so hoher mage der margravinne lip ### daz wir gerne dienten ich vnde sine man ### vnd soldes vnder chrone da cen Bvrgonden gan
###### 1676 | ### Div rede Rvedgeren dvhte harte gvt ### vnd ovch Gotelinde ia frevte sich in der mvt ### do trvgen an di helde daz si ce wibe nam ### Giselher der edele als ez wol chvenege gezam
| ### Swaz sich sol gefvegen wer moeht daz vndersten ### man bat di ivnchvrowen hin ce hove gen ### do swor man im ze gebene daz wennechliche wip ### do lobt ovch er ce minnen den ir vil minnechlichen lip
###### 1678 | ### Man beshiet der ivnchvrowen bverge vnde lant ### des sicherte da mit eiden des edeln chveniges hant ### vnde ovch der herre Gernot daz wrde daz getan ### do sprach der margrave sit ich der bverge nine han
###### 1679 | ### sol ich <iv> mit triwen immer wesen holt ### ich gibe ce miner tohter silber vnde golt ### so hvndert sovmære meiste mvegen tragen ### daz ich des heldes magen nach eren mvege wol behagen
| ### Do hiez man si beide sten an einen rinch ### nach gewonheite vil manich ivngelinch ### in vroelichem mvte in cegegen stvnt ### si gedahten in ir sinnen so noch di tvmmen gerne tvnt
###### 1681 | ### Do man begonde vragen di minnechlichen meit ### ob si den recken wolde ein teil was ez ir leit ### vnt dahte doch ce nenemne den wætlichen man ### si shamte sich der vrage so manich magt hat getan
###### 1682 | ### Ir riet ir vater Rvedger daz si spreche ia ### vnt daz si in gerne næme vil schiere do was da ### mit sinen wizen handen der si vmbesloz ### Giselher der edele swi lvecel si sin doch genoz
| ### Do sprach der margrave ir edele chvenege rich ### als ir nv wider ritet daz ist gewonlich ### heim hin zen Bvrgonden so gip ich iv min chint ### daz ir si mit iv fveret daz gelobten si sint [374b]
###### 1684 | ### Swaz man do shalles horte den mvsen si do lan ### man hiez di ivnchvrowen cer kemnaten gan ### vnd ovch di geste slaffen vnd rwen an den tach ### do bereitte man di spise der wirt ir gvetliche pflach
###### 1685 | ### Do si enbizzen waren si wolden dannen varn ### gegen der Hivnen landen daz heiz ich wol bewarn ### sprach der wirt vil edele ir svlt ovch hi bestan ### wand ich so lieber geste selten hie iht gewnnen han
| ### Des antwrte Danchwart iane mages niht gesin ### wa nemt ir di spise daz brot vnd ovch den win ### daz ir so manigen recken noch hinte mveset han ### do daz der wirt gehorte er sprach ir svlt di rede lan
###### 1687 | ### Mine vil lieben herren ir svlt mir niht versagen ### ia gebe ich iv di spise ce vierzehen tagen ### mit allem iwerem gesinde daz mit iv her ist chomen ### mir hat der kvenech Ecel noch vil wenich iht genomen
###### 1688 | ### Swi sere si sich werten si mvsen da bestan ### vnz an den vierden morgen do wart da getan ### von des wirtes milte daz verre wart geseit ### er gap den sinen gesten beidiv ross vnd chleit
| ### Ezen chvnde niht wern langer si mvsen dannen varn ### Rvedger der chvene vil wenich iht gesparn ### chond vor siner milte swes iemen gerte nemen ### daz versagete er niemen ez mvse in allen gezemen
###### 1690 | ### Ir edel ingesinde braht fver daz tor ### gesatelt vil der moere do chom zv zin da vor ### vil der vremden recken si trvgen schilde enhant ### wande si wolden ritten in daz Eceln lant
###### 1691 | ### Der wirt do sine gabe bot veber al ### ê daz di edeln geste choemen fvr den sal ### er chonde miltechliche mit grozen eren leben ### die sine tohter shoene di het er Giselher gegeben
| ### Do gap er Gvnthere dem helde lobelich ### daz wol trvch mit eren der edel fvrste rich ### swi selten er gabe enpfienge ein wafenlich gewant ### dar nah [375a] neich do Gventher des edeln Rvedgeres hant
###### 1693 | ### Do gap er Gernote ein waffen gvt genvch ### daz er sit in stvrme vil herlichen trvch ### der gabe im vil wol gonde des margraven wip ### da von der gvte Rvedger sit mvse vliesen den lip
###### 1694 | ### Gotelint bot Hagenen als ir vil wol gezam ### ir minnechlichen gabe sit si der kvnech nam ### daz er ovh an ir stivre zv der hohgecit ### von ir varn niht solde doh widerredete er iz sit
| ### Alles des ich ie gesach sprach do Hagene ### sone gert ich niht mere hinnen ce tragene ### niwan ienes shildes dort an iener want ### den wolde ich gerne fveren in daz Eceln lant
###### 1696 | ### Do div margravinne Hagen rede vernam ### ez mante si ir leides weinen si gezam ### do gedahte si vil tivre an Nvodvnges tot ### den het erslagen Witege da von so het si iamers not
###### 1697 | ### Si sprach zv dem degene den schilt wil ich iv geben ### daz wolde got von himele daz er noch solde leben ### der in da trvch enhende der lag in stvrme tot ### den mvoz ich <imer> weinen des gat mir armem wibe not
| ### Div edele margravinne von dem sedele gie ### mit ir vil wizen handen si den schilt gevie ### div vrowe trvg in Hagenen er nam in an di hant ### div gabe was mit eren an den recken gewant
###### 1699 | ### Ein hvlft von liehtem pfelle ob siner varwe lach ### bezzern shilt deheinen belvhte ni der tach ### von edelm gesteine swer sin hete gegert ### ce chovffen an der choste was er wol tvsent marche wert
###### 1700 | ### Den schilt hiez do Hagene tragen vor im dan ### do begonde Danchwart hince hove gan ### dem gap vil richiv <kleider> des margraven chint ### div trvch er cen Hivnen vil harte herliche sint
| ### Allez daz der gabe von in wart [375b] genomen ### in ir deheines hende wær ir niht bechomen ### wan dvrh des wirtes liebe derz in so schone bot ### sit wrdens im so vient daz si in mvsen slahen tot
###### 1702 | ### Volker der snelle mit siner videlen dan ### gie gezogenliche fver Gotelinde stan ### er videlte sveze doene vnd sanch ir siniv liet ### da mit nam er vrlovp do er von Bechelarn schiet
###### 1703 | ### Ir hiez div margravinne eine lade tragen ### von frivntlicher gabe mveget ir horen sagen ### dar vz nam si zwelf povge vnde spiens im an di hant ### di svlt ir hinnen fveren in daz Eceln lant
| ### Vnde svlt dvrh minen willen si ce hove tragen ### swenne ir wider wendet daz man mir mvege sagen ### wi ir mir habt gedienet da cer hohgecit ### des div vrowe gerte vil wol leist er daz sit
###### 1705 | ### Do sprach der wirt cen gesten ir svlt deste sanfter varn ### ich wil ivch selbe leiten vnd heizen wol bewarn ### daz iv vf der straze niemen mvge geschaden ### do wrden sine sovme harte schiere geladen
###### 1706 | ### Der wirt wart wol bereitet mit fvnfhvndert man ### mit rossen vnd mit chleidern di fvrt er mit im dan ### vil harte herlichen zv der hohgezit ### der einer mit dem lebene chom ni ze Bechelaren sit
| ### Mit chvsse minnechliche der wirt do dannen schiet ### also tet ovch Giselher als im sin tvgent riet ### mit vmbslozen armen si trvten schoniv wip ### daz mvse sit beweinen vil maniger ivnchvrowen lip
###### 1708 | ### Do wrden allenthalben div venster vf getan ### der wirt mit sinen mannen cen rossen wolde gan ### ich wæn ir herce in sagete div crefftechlichen leit ### da weinte manich vrowe vnd manich wætlichiv meit
###### 1709 | ### Nach ir lieben frivnden genvge heten ser ### di si ce Bechelaren gesahen nimmer mer ### doch riten si mit vrevden nider vber sant ### ce tal bi Tvnowe vz in daz hivnisshe lant
| ### Do sprach cen Bvrgonden der ritter [376a] vil gemeit ### Rvedger der edele ian svln niht verdeit ### wesen vnser mære daz wir zen Hivnen chomen ### im hat der kvenich Ecel ni so libes niht vernomen
###### 1711 | ### Ze tal dvrch Osterriche der bote balde reit ### den livten allenthalben wart daz wol geseit ### daz di helde chomen von Wormez veber Rin ### des kveneges ingesinde chonde ez niht lieber gesin
###### 1712 | ### Di boten fver strichen mit den mæren ### daz di Nibelvnge zen Hivnen wæren ### dv solt si wol enpfahen Criemhilt vrowe min ### dir choment nach vil grozen eren di vil lieben brvder din
###### 1713 | ### <Criemhilt> div vrowe in ein venster stvnt ### si warte nach den magen so noch <frivnde> nach frivnden tvnt ### von ir vaterlande sach si manigen man ### der kvenich vriehs ovch div mære vor liebe er lachen began
###### 1714 | ### Nv wol mich miner vrevden sprach do Criemhilt ### hi bringent mine mage vil manigen niwen schilt ### von halsperge wiz swer nemen welle golt ### der gedenche miner leide vnd wil im immer wesen holt

<<< Übersicht <<< vorige Seite nächste Seite >>>